@@ -1,3 +1,4 @@
+# -*- coding:utf-8 -*-
 #
 # Copyright 2020, Xiaomi.
 # All rights reserved.
@@ -11,7 +12,6 @@ from talos.thrift.consumer.ttypes import UpdateOffsetRequest
 from talos.thrift.message.ttypes import GetPartitionOffsetRequest
 from talos.consumer.MessageCheckpointer import MessageCheckpointer
 from talos.utils import Utils
-from talos.thrift.common.ttypes import GalaxyTalosException
 import traceback
 import logging
 import time
@@ -43,7 +43,7 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
         if self.consumerConfig.is_reset_offset_when_start():
             readingStartOffset = self.reset_read_start_offset(
                 self.consumerConfig.get_reset_offset_value_when_start())
-        elif (not self.outerCheckPoint) and self.outerCheckPoint >= 0:
+        elif self.outerCheckPoint and self.outerCheckPoint >= 0:
             readingStartOffset = self.outerCheckPoint
             # burn after reading the first time
             self.outerCheckPoint = None
@@ -91,10 +91,11 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             if self.logger.isEnabledFor:
                 self.logger.debug("Reading message from offset: " + str(self.startOffset.value) +
                                   " of partition: " + str(self.topicAndPartition.partitionId))
-
+            startFetchTime = Utils.current_time_mills()
             messageList = self.simpleConsumer.fetch_message(startOffset=self.startOffset.value,
                                                             maxFetchedNumber=self.consumerConfig.get_max_fetch_msg_num())
             self.lastFetchTime = Utils.current_time_mills()
+            self.consumerMetrics.mark_fetch_duration(self.lastFetchTime - startFetchTime)
 
             # return when no message got
             if not messageList or len(messageList) == 0:
@@ -105,12 +106,14 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             # Note: We guarantee the committed offset must be the messages that
             # have been processed by user 's MessageProcessor;
             self.finishedOffset = messageList[len(messageList) - 1].messageOffset
+            startProcessTime = Utils.current_time_mills()
             self.messageProcessor.process(messageList, self)
+            self.consumerMetrics.mark_process_duration(
+                Utils.current_time_mills() - startProcessTime)
             self.startOffset.get_and_set(self.finishedOffset + 1)
             self.check_and_commit(True)
         except Exception as e:
-            if isinstance(e, GalaxyTalosException):
-                self.logger.error(e.errMsg)
+            self.consumerMetrics.mark_fetch_or_process_failed_times()
             self.logger.error("Error when getting messages from topic: "
                               + self.topicAndPartition.topicTalosResourceName.topicTalosResourceName
                               + " partition: " + str(self.topicAndPartition.partitionId)
@@ -120,7 +123,7 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
 
     def query_start_offset(self):
         queryOffsetRequest = QueryOffsetRequest(self.consumerGroup, self.topicAndPartition)
-        queryOffsetResponse = self.consumerClient.query_offset(queryOffsetRequest)
+        queryOffsetResponse = self.queryOffsetClient.query_offset(queryOffsetRequest)
 
         committedOffset = queryOffsetResponse.msgOffset
         # 'committedOffset == -1' means not exist last committed offset
@@ -155,12 +158,9 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             self.commit_offset(messageOffset)
             return True
         except Exception as e:
-            if isinstance(e, GalaxyTalosException):
-                self.logger.error(e.errMsg)
             self.logger.error("Error when getting messages from topic: " +
                               self.topicAndPartition.topicTalosResourceName.topicTalosResourceName()
-                              + " partition: " + str(self.topicAndPartition.partitionId)
-                              + str(traceback.format_exc()))
+                              + " partition: " + str(self.topicAndPartition.partitionId) + e.message)
             return False
 
     def commit_offset(self, messageOffset=None):
@@ -191,8 +191,6 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             try:
                 self.inner_checkpoint()
             except Exception as e:
-                if isinstance(e, GalaxyTalosException):
-                    self.logger.error(e.errMsg)
                 # when commitOffset failed, we just do nothing;
                 self.logger.error("commit offset error, we skip to it"
                                   + str(traceback.format_exc()))
@@ -217,11 +215,8 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             self.commit_offset(commitOffset)
             return True
         except Exception as e:
-            if isinstance(e, GalaxyTalosException):
-                self.logger.error(e.errMsg)
             self.logger.error("Error when getting messages from topic: " +
                               self.topicAndPartition.topicTalosResourceName.topicTalosResourceName
-                              + " partition: " + str(self.topicAndPartition.partitionId)
-                              + str(traceback.format_exc()))
+                              + " partition: " + str(self.topicAndPartition.partitionId), e)
             return False
 
