@@ -175,7 +175,7 @@ class TalosProducer(object):
                     self.logger.error("addUserMessage global lock wait is interrupt."
                                       + e.message)
 
-        if not partitionId:
+        if partitionId is None:
             self.do_add_user_message(msgList)
         else:
             userMessageList = []
